@@ -1,11 +1,13 @@
 // Copyright (C) 2022 The Qt Company Ltd.
 // SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
 
-#include <QtCore/qglobal.h>
-
 #ifndef QTLABSSETTINGSEXPORTS_H
 #define QTLABSSETTINGSEXPORTS_H
 
+#include <QtCore/qcompilerdetection.h>
+#include <QtCore/qtconfigmacros.h> // Q_LABSSETTINGS_EXPORT
+#include <QtCore/qtdeprecationmarkers.h> // QT_IF_DEPRECATED_SINCE
+
 #if defined(QT_SHARED) || !defined(QT_STATIC)
 #  if defined(QT_BUILD_LABSSETTINGS_LIB)
 #    define Q_LABSSETTINGS_EXPORT Q_DECL_EXPORT
@@ -20,6 +22,7 @@
 /* outside library -> inline decl + defi */
 /* static builds treat everything as part of the library, so they never inline */
 #  define QT_LABSSETTINGS_INLINE_SINCE(major, minor) inline
+#  define QT_LABSSETTINGS_CONSTEXPR_INLINE_SINCE(major, minor) constexpr
 #  define QT_LABSSETTINGS_INLINE_IMPL_SINCE(major, minor) 1
 #elif defined(QT_LABSSETTINGS_BUILD_REMOVED_API)
 /* inside library, inside removed_api.cpp:
@@ -28,6 +31,8 @@
  * definition is always available */
 #  define QT_LABSSETTINGS_INLINE_SINCE(major, minor) \
     QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
+#  define QT_LABSSETTINGS_CONSTEXPR_INLINE_SINCE(major, minor) \
+    QT_IF_DEPRECATED_SINCE(major, minor, constexpr, /* not inline */)
 #  define QT_LABSSETTINGS_INLINE_IMPL_SINCE(major, minor) 1
 #else
 /* inside library, outside removed_api.cpp:
@@ -35,6 +40,8 @@
  * remove deprecated API -> inline decl, defi */
 #  define QT_LABSSETTINGS_INLINE_SINCE(major, minor) \
     QT_IF_DEPRECATED_SINCE(major, minor, inline, /* not inline */)
+#  define QT_LABSSETTINGS_CONSTEXPR_INLINE_SINCE(major, minor) \
+    QT_IF_DEPRECATED_SINCE(major, minor, constexpr, /* not inline */)
 #  define QT_LABSSETTINGS_INLINE_IMPL_SINCE(major, minor) \
     QT_IF_DEPRECATED_SINCE(major, minor, 1, 0)
 #endif
